@@ -5,6 +5,8 @@ from .common import (
     save_node_config
 )
 
+from pyhmy import Typgpy
+
 
 class ResetNode(Exception):
     """
@@ -20,4 +22,8 @@ class ResetNode(Exception):
 class InvalidWalletPassphrase(InvalidToken):
     """
     Exception raised if passphrase is invalid
-    """
\ No newline at end of file
+    """
+
+    def __init__(self):
+        super(InvalidToken, self).__init__(f"Re-authenticate wallet passphrase with "
+                                           f"'{Typgpy.OKGREEN}auto-node auth-wallet{Typgpy.ENDC}'")
