@@ -32,13 +32,14 @@ def _get_harmony_pid():
 
 def _get_process_info(pid):
     assert isinstance(pid, bytes)
-    if pid == b'0':
-        return pid
+    pid = pid.strip()
     try:
-        raw_output = subprocess.check_output(["ls", "-ld", f"/proc/{pid.decode().strip()}"], env=os.environ).strip()
-        lst = raw_output.split(' '.encode())
-        return b''.join(lst[1:-1]) if len(lst) >= 3 else b'0'
-    except (subprocess.TimeoutExpired, subprocess.CalledProcessError):
+        if int(pid) <= 0:
+            return b'0'
+        proc_start = subprocess.check_output(["ps", "-p", pid.decode(), "-o", "lstart="], env=os.environ).strip()
+        proc_command = subprocess.check_output(["ps", "-p", pid.decode(), "-o", "command="], env=os.environ).strip()
+        return proc_start + b' ' + proc_command
+    except (subprocess.TimeoutExpired, subprocess.CalledProcessError, ValueError):
         return b'0'
 
 
@@ -52,20 +53,21 @@ def _derive_wallet_encryption_key():
     """
     Create the wallet encryption key based on:
         PBKDF2HMAC(PID(harmony) + ProcessInfo(harmony), salt=HMAC(node_bls_public_keys, Validator_Addr, Validator_ID))
-    Where node_config* are all node_configs as a dict, except for encrypted values.
 
     This means that the encryption key is only valid for when AutoNode has a harmony node process running.
     """
-    pid = _get_harmony_pid()
-    proc_info = _get_process_info(pid)
+    pid = _get_harmony_pid().strip()
+    proc_info = _get_process_info(pid).strip()
+    salt = _get_node_based_salt()
     kdf = PBKDF2HMAC(
         algorithm=hashes.SHA256(),
         length=32,
-        salt=_get_node_based_salt().strip(),
-        iterations=50,
+        salt=salt,
+        iterations=10000,
         backend=default_backend()
     )
-    return base64.urlsafe_b64encode(kdf.derive(pid.strip() + proc_info.strip()))
+    data = pid + b' ' + proc_info
+    return base64.urlsafe_b64encode(kdf.derive(data))
 
 
 def encrypt_wallet_passphrase(passphrase):
